@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '3.1.0';
-use 5.016;
+$Git::Hooks::CheckJira::VERSION = '3.1.1';
+use v5.16.0;
 use utf8;
 use Log::Any '$log';
 use Git::Hooks;
@@ -532,7 +532,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
