@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Hooks::CheckRewrite;
 # ABSTRACT: Git::Hooks plugin for checking against unsafe rewrites
-$Git::Hooks::CheckRewrite::VERSION = '3.1.0';
-use 5.016;
+$Git::Hooks::CheckRewrite::VERSION = '3.1.1';
+use v5.16.0;
 use utf8;
 use Path::Tiny;
 use Log::Any '$log';
@@ -181,7 +181,7 @@ Git::Hooks::CheckRewrite - Git::Hooks plugin for checking against unsafe rewrite
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
