@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Hooks::CheckWhitespace;
 # ABSTRACT: Git::Hooks plugin for checking whitespace errors
-$Git::Hooks::CheckWhitespace::VERSION = '3.1.0';
-use 5.016;
+$Git::Hooks::CheckWhitespace::VERSION = '3.1.1';
+use v5.16.0;
 use utf8;
 use Log::Any '$log';
 use Git::Hooks;
@@ -114,7 +114,7 @@ Git::Hooks::CheckWhitespace - Git::Hooks plugin for checking whitespace errors
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
