@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Hooks::GerritChangeId;
 # ABSTRACT: Git::Hooks plugin to insert a Change-Id in a commit message
-$Git::Hooks::GerritChangeId::VERSION = '3.1.0';
-use 5.016;
+$Git::Hooks::GerritChangeId::VERSION = '3.1.1';
+use v5.16.0;
 use utf8;
 use Carp;
 use Log::Any '$log';
@@ -103,7 +103,7 @@ Git::Hooks::GerritChangeId - Git::Hooks plugin to insert a Change-Id in a commit
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
