@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Message;
 # ABSTRACT: A Git commit message
-$Git::Message::VERSION = '3.1.0';
-use 5.016;
+$Git::Message::VERSION = '3.1.1';
+use v5.16.0;
 use utf8;
 use Carp;
 
@@ -189,7 +189,7 @@ Git::Message - A Git commit message
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
